@@ -397,7 +397,7 @@ def worker(pid, message):
         except Exception as e:
             logging.error(e)
         if resp:
-            if hash('make_response'):
+            if hasattr(resp, 'make_response'):
                 response_text = resp.make_response(config, aws)
                 aws.send_msg(resp.endpoint, response_text)
                 logging.info(f'response:{resp.data}')
